==> wurld-0.3.tar.gz: wurld-0.3/src/Collidable.cc <==
/*===========================================================================*\

   $Id$

   Copyright (C) 2007 Michael A. Muller

   Permission is granted to use, modify and redistribute this code,
   providing that the following conditions are met:
 
   1) This copyright/licensing notice must remain intact.
   2) If the code is modified and redistributed, the modifications must 
   include documentation indicating that the code has been modified.
   3) The author(s) of this code must be indemnified and held harmless
   against any damage resulting from the use of this code.

   This code comes with ABSOLUTELY NO WARRANTEE, not even the implied 
   warrantee of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  

\*===========================================================================*/

#include "Collidable.h"

#include <spug/UnsupportedOperationException.h>

using namespace spug;

const Poly &Collidable::getPoly() const {
   throw UnsupportedOperationException("Collidable::getPoly");
}

AxisBox Collidable::getAxisBox() const {
   throw UnsupportedOperationException("Collidable::getAxisBox");
}

const Collidable::Sphere &Collidable::getSphere() const {
   throw UnsupportedOperationException("Collidable::getSphere");
}

Vector Collidable::getVelocity() const {
   return Vector();
}

std::ostream &operator <<(std::ostream &out, const Collidable &coll) {
   Collidable::Types types = coll.getTypes();
   out << "Collidable " << &coll << " {\n";
   if (types.includes(Collidable::poly))
      out << "   " << coll.getPoly() << "\n";
   if (types.includes(Collidable::axisBox))
      out << "   " << coll.getAxisBox() << "\n";
   if (types.includes(Collidable::sphere)) {
      const Collidable::Sphere &sphere = coll.getSphere();
      out << "   Sphere(origin = " << sphere.center << ", radius = "
	 << sphere.radius << ")\n";
   }
   out << "   velocity = " << coll.getVelocity() << "\n";
   out << "}\n";

   return out;
}

==> wurld-0.4.tar.gz: wurld-0.4/src/Collidable.cc <==
/*===========================================================================*\

   $Id$

   Copyright (C) 2007 Michael A. Muller

   Permission is granted to use, modify and redistribute this code,
   providing that the following conditions are met:
 
   1) This copyright/licensing notice must remain intact.
   2) If the code is modified and redistributed, the modifications must 
   include documentation indicating that the code has been modified.
   3) The author(s) of this code must be indemnified and held harmless
   against any damage resulting from the use of this code.

   This code comes with ABSOLUTELY NO WARRANTEE, not even the implied 
   warrantee of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  

\*===========================================================================*/

#include "Collidable.h"

#include <spug/UnsupportedOperationException.h>
#include "Sphere.h"

using namespace spug;

const Poly &Collidable::getPoly() const {
   throw UnsupportedOperationException("Collidable::getPoly");
}

AxisBox Collidable::getAxisBox() const {
   throw UnsupportedOperationException("Collidable::getAxisBox");
}

Sphere Collidable::getSphere() const {
   throw UnsupportedOperationException("Collidable::getSphere");
}

Vector Collidable::getVelocity() const {
   return Vector();
}

std::ostream &operator <<(std::ostream &out, const Collidable &coll) {
   Collidable::Types types = coll.getTypes();
   out << "Collidable " << &coll << " {\n";
   if (types.includes(Collidable::poly))
      out << "   " << coll.getPoly() << "\n";
   if (types.includes(Collidable::axisBox))
      out << "   " << coll.getAxisBox() << "\n";
   if (types.includes(Collidable::sphere)) {
      const Sphere &sphere = coll.getSphere();
      out << "   Sphere(origin = " << sphere.center << ", radius = "
	 << sphere.radius << ")\n";
   }
   out << "   velocity = " << coll.getVelocity() << "\n";
   out << "}\n";

   return out;
}
